# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.4.1~53ca43a',
    built_at='2024-03-19 11:37:40Z',
    sha='53ca43aee6f8090356ab257f646cf1ea6b6f1629',
    branch='HEAD',
    tag='v4.4.1',
)
